@@ -31,7 +31,7 @@ const (
 	exampleText = `
   # Start a %s shell in the Docker container:
   cdebug exec -it mycontainer
-  cdebug exec -it docker://my-container
+  cdebug exec -it docker://mycontainer
 
   # Execute a command in the Docker container:
   cdebug exec mycontainer cat /etc/os-release
@@ -273,7 +273,9 @@ func debuggerName(name string, runID string) string {
 
 var (
 	simpleEntrypoint = template.Must(template.New("user-entrypoint").Parse(`
-set -euo pipefail
+set -eu
+
+export CDEBUG_ROOTFS=/
 
 if [ "${HOME:-/}" != "/" ]; then
 	ln -s /proc/{{ .TARGET_PID }}/root/ ${HOME}target-rootfs
@@ -285,7 +287,7 @@ exec {{ .Cmd }}
 `))
 
 	chrootEntrypoint = template.Must(template.New("chroot-entrypoint").Parse(`
-set -euo pipefail
+set -eu
 
 CURRENT_PID=$(sh -c 'echo $PPID')
 
@@ -298,11 +300,13 @@ if [ ${CURRENT_NIX_INODE} -ne ${TARGET_NIX_INODE} ]; then
 fi
 {{ end }}
 
-ln -s /proc/${CURRENT_PID}/root/bin/ /proc/{{ .TARGET_PID }}/root/.cdebug-{{ .ID }}
+ln -s /proc/${CURRENT_PID}/root/ /proc/{{ .TARGET_PID }}/root/.cdebug-{{ .ID }}
+
+export CDEBUG_ROOTFS=/.cdebug-{{ .ID }}
 
 cat > /.cdebug-entrypoint.sh <<EOF
 #!/bin/sh
-export PATH=$PATH:/.cdebug-{{ .ID }}
+export PATH=$PATH:$CDEBUG_ROOTFS/bin:$CDEBUG_ROOTFS/usr/bin:$CDEBUG_ROOTFS/sbin:$CDEBUG_ROOTFS/usr/sbin:$CDEBUG_ROOTFS/usr/local/bin:$CDEBUG_ROOTFS/usr/local/sbin
 
 chroot /proc/{{ .TARGET_PID }}/root {{ .Cmd }}
 EOF
@@ -329,7 +333,7 @@ func debuggerEntrypoint(
 				"IsNix":      strings.Contains(image, "nixery"),
 				"Cmd": func() string {
 					if len(cmd) == 0 {
-						return ""
+						return "sh"
 					}
 					return "sh -c '" + strings.Join(shellescape(cmd), " ") + "'"
 				}(),
@@ -346,7 +350,7 @@ func debuggerEntrypoint(
 				if len(cmd) == 0 {
 					return "sh"
 				}
-				return strings.Join(shellescape(cmd), " ")
+				return "sh -c \"" + strings.Join(shellescape(cmd), " ") + "\""
 			}(),
 		},
 	)
